summaryrefslogtreecommitdiffstats
path: root/libkdeedu/kdeeduplot/kplotwidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdeedu/kdeeduplot/kplotwidget.h')
-rw-r--r--libkdeedu/kdeeduplot/kplotwidget.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/libkdeedu/kdeeduplot/kplotwidget.h b/libkdeedu/kdeeduplot/kplotwidget.h
index 5ed550ec..212c5234 100644
--- a/libkdeedu/kdeeduplot/kplotwidget.h
+++ b/libkdeedu/kdeeduplot/kplotwidget.h
@@ -95,11 +95,11 @@ public:
*/
virtual void clearObjectList() { ObjectList.clear(); update(); }
/**@short replace an item in the KPlotObject list.
*@param i the index of th item to be replaced
*@param o pointer to the replacement KPlotObject
*/
- virtual void replaceObject( int i, KPlotObject *o ) { ObjectList.replace( i, o ); }
+ virtual void tqreplaceObject( int i, KPlotObject *o ) { ObjectList.tqreplace( i, o ); }
/**@return the number of KPlotObjects in the list
*/
@@ -212,7 +212,7 @@ public:
KPlotAxis LeftAxis;
protected:
- /**@short the paint event handler, executed when update() or repaint() is called.
+ /**@short the paint event handler, executed when update() or tqrepaint() is called.
*/
virtual void paintEvent( TQPaintEvent* /* e */ );
@@ -95,11 +95,11 @@ public:
*/
virtual void clearObjectList() { ObjectList.clear(); update(); }
- /**@short replace an item in the KPlotObject list.
- *@param i the index of th item to be replaced
- *@param o pointer to the replacement KPlotObject
+ /**@short tqreplace an item in the KPlotObject list.
+ *@param i the index of th item to be tqreplaced
+ *@param o pointer to the tqreplacement KPlotObject
*/